==> eugene-maven-plugin-2.6.3-sources.jar: org/nuiton/eugene/plugin/writer/YamlModelChainedFileWriter.java <==
package org.nuiton.eugene.plugin.writer;

/*
 * #%L
 * EUGene :: Maven plugin
 * $Id: YamlModelChainedFileWriter.java 1243 2013-05-05 08:32:43Z tchemit $
 * $HeadURL: http://svn.nuiton.org/svn/eugene/tags/eugene-2.6.3/eugene-maven-plugin/src/main/java/org/nuiton/eugene/plugin/writer/YamlModelChainedFileWriter.java $
 * %%
 * Copyright (C) 2006 - 2013 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */

/**
 * To create a memory model from yaml model files.
 *
 * @author tchemit
 * @plexus.component role="org.nuiton.eugene.writer.ChainedFileWriter" role-hint="yamlModel2Memory"
 * @since 2.6.3
 */
public class YamlModelChainedFileWriter extends BaseChainedFileWriterToMemoryModel {

    public YamlModelChainedFileWriter() {
        super();
    }

    @Override
    protected String getInputType() {
        return "yaml";
    }

    @Override
    public String getInputProtocol() {
        return "yamlmodel";
    }

    @Override
    public boolean acceptInclude(String include) {
        return include.startsWith("yaml:") ||
               include.endsWith(".yamlobjectmodel") ||
               include.endsWith(".yamlstatemodel");
    }

    @Override
    public String getDefaultIncludes() {
        return "**/*.yaml*model";
    }

    @Override
    public String getDefaultInputDirectory() {
        return "src/main/models";
    }

    @Override
    public String getDefaultOutputDirectory() {
        return "java";
    }

    @Override
    public String getDefaultTestInputDirectory() {
        return "src/test/models";
    }

    @Override
    public String getDefaultTestOutputDirectory() {
        return "test-java";
    }
}

==> eugene-maven-plugin-2.7-sources.jar: org/nuiton/eugene/plugin/writer/YamlModelChainedFileWriter.java <==
package org.nuiton.eugene.plugin.writer;

/*
 * #%L
 * EUGene :: Maven plugin
 * $Id: YamlModelChainedFileWriter.java 1243 2013-05-05 08:32:43Z tchemit $
 * $HeadURL: http://svn.nuiton.org/svn/eugene/tags/eugene-2.7/eugene-maven-plugin/src/main/java/org/nuiton/eugene/plugin/writer/YamlModelChainedFileWriter.java $
 * %%
 * Copyright (C) 2006 - 2013 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */

/**
 * To create a memory model from yaml model files.
 *
 * @author tchemit
 * @plexus.component role="org.nuiton.eugene.writer.ChainedFileWriter" role-hint="yamlModel2Memory"
 * @since 2.6.3
 */
public class YamlModelChainedFileWriter extends BaseChainedFileWriterToMemoryModel {

    public YamlModelChainedFileWriter() {
        super();
    }

    @Override
    protected String getInputType() {
        return "yaml";
    }

    @Override
    public String getInputProtocol() {
        return "yamlmodel";
    }

    @Override
    public boolean acceptInclude(String include) {
        return include.startsWith("yaml:") ||
               include.endsWith(".yamlobjectmodel") ||
               include.endsWith(".yamlstatemodel");
    }

    @Override
    public String getDefaultIncludes() {
        return "**/*.yaml*model";
    }

    @Override
    public String getDefaultInputDirectory() {
        return "src/main/models";
    }

    @Override
    public String getDefaultOutputDirectory() {
        return "java";
    }

    @Override
    public String getDefaultTestInputDirectory() {
        return "src/test/models";
    }

    @Override
    public String getDefaultTestOutputDirectory() {
        return "test-java";
    }
}
